@@ -1,10 +1,10 @@
 /* This file is a part of groinc
  * 
  * Copyright (C) 2006, 2007 Sarzyniec Luc <olbat@xiato.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,9 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- * 
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  * see the COPYING file for more informations */
 
 #include "globals_filter.h"
@@ -31,7 +30,7 @@ int check_options()
 	end = 0;
 	if (*filterregexstr)
 	{
-		if (regcomp(&filterregex,filterregexstr,0))
+		if (regcomp(&filterregex,filterregexstr,REG_NOSUB))
 		{
 			co_error = filterregexstr;
 			end = 1;
@@ -47,8 +46,9 @@ int check_options()
 		}
 		else
 		{
-			ipproto = (unsigned char) tmp;
+			ipproto = (unsigned int) tmp;
 		}
+		filter_transport = 1;
 	}
 	if (*ethprotoname)
 	{
@@ -60,8 +60,9 @@ int check_options()
 		}
 		else
 		{
-			ethproto = (unsigned char) tmp;
+			ethproto = (unsigned int) tmp;
 		}
+		filter_network = 1;
 	}
 	if (*protoname)
 	{
@@ -73,40 +74,70 @@ int check_options()
 		}
 		else
 		{
-			proto = (unsigned char) tmp;
+			proto = (unsigned int) tmp;
 		}
+		filter_datalink = 1;
 	}
 	if (*fsourceport)
 	{
 		lsourceport = my_atoi(fsourceport,10);
+		filter_transport = 1;
 	}
 	if (*fdestport)
 	{
 		ldestport = my_atoi(fdestport,10);
+		filter_transport = 1;
 	}
 	if (*fglobalport)
 	{
 		lglobalport = my_atoi(fglobalport,10);
+		filter_transport = 1;
 	}
 	if (*fglobalip)
 	{
 		lglobalip = ipv4_aton(fglobalip);
+		filter_network = 1;
 	}
 	if (*fsourceip)
 	{
 		lsourceip = ipv4_aton(fsourceip);
+		filter_network = 1;
 	}
 	if (*fdestip)
 	{
 		ldestip = ipv4_aton(fdestip);
+		filter_network = 1;
 	}
 	if (*fdestmac)
 	{
-		ldestmac = (__u8 *) mac_aton(fdestmac);
+		mac_aton(fdestmac,ldestmac);
+		filter_datalink = 1;
 	}
 	if (*fsourcemac)
 	{
-		lsourcemac = (__u8 *) mac_aton(fsourcemac);
+		mac_aton(fsourcemac,lsourcemac);
+		filter_datalink = 1;
 	}
+	if (*flimitnb)
+	{
+		llimitnb = (long int) my_atoi(flimitnb,10);
+	}
+	if (*ftimelimit)
+	{
+		gettimeofday(&timelimit,0);
+		timelimit.tv_sec = timelimit.tv_sec + my_atoi(ftimelimit,10);
+	}
+
+	if ((!ldestip) && (!ldestport) && (!lsourceip) && (!lsourceport)
+	&& (!lglobalip) && (!lglobalport) && (mac_null(lsourcemac)) 
+	&& (mac_null(ldestmac)) && (ipproto == IPPROTO_RAW) && (ethproto == ETHPROTO_RAW))
+	{
+		nofilter = 1;
+	}
+	else
+	{
+		nofilter = 0;
+	}
+
 	return end;
 }
